import React, { useState } from 'react';
import { FeatherIcon as GatherIcon } from 'lucide-react';
import ResourceSelectionModal from './ResourceSelectionModal';
import { Pet } from '../types/Pet';
import { updatePetAction } from '../services/api/api';
import { PetAction } from '../types/PetUpdateActionRequest';

interface GatherResourcesButtonProps {
  pet: Pet;
  onGatherStart: () => void;
  onGatherComplete: () => void;
}

const resourceToActionMap: Record<string, PetAction> = {
  wisdom: 'GATHERING_WISDOM',
  gold: 'GATHERING_GOLD',
  food: 'GATHERING_FOOD'
};

export default function GatherResourcesButton({ pet, onGatherStart, onGatherComplete }: GatherResourcesButtonProps) {
  const [isModalOpen, setIsModalOpen] = useState(false);
  const [isGathering, setIsGathering] = useState(false);

  const handleGatherStart = async (resourceType: string) => {
    setIsGathering(true);
    onGatherStart();

    try {
      const petAction = resourceToActionMap[resourceType];
      await updatePetAction(pet.id, { petAction });
      onGatherComplete();
    } catch (error) {
      console.error('Failed to gather resources:', error);
    } finally {
      setIsGathering(false);
      setIsModalOpen(false);
    }
  };

  return (
    <>
      <button
        onClick={() => setIsModalOpen(true)}
        disabled={isGathering}
        className={`flex items-center justify-center space-x-2
          bg-amber-900/30 hover:bg-amber-800/50
          border-2 border-amber-500/50 rounded-lg p-4
          transition-all duration-300 transform hover:scale-105 w-full
          ${isGathering ? 'opacity-50 cursor-not-allowed' : ''}`}
      >
        <GatherIcon className="w-6 h-6" />
        <span>{isGathering ? 'Gathering...' : 'Gather Resources'}</span>
      </button>

      <ResourceSelectionModal
        isOpen={isModalOpen}
        onClose={() => setIsModalOpen(false)}
        onGather={handleGatherStart}
        pet={pet}
        isGathering={isGathering}
      />
    </>
  );
}